@@ -71,7 +71,7 @@ class Form(object):
 
     def __init__(self, config, item=None, dbsession=None, translate=None,
                  change_page_callback={}, renderers={}, request=None,
-                 csrf_token=None):
+                 csrf_token=None, eval_url=None):
         """Initialize the form with ``Form`` configuration instance and
         optional an SQLAlchemy mapped object.
 
@@ -91,13 +91,19 @@ class Form(object):
         when using in connection with ringo)
         :csrf_token: Token to which will be included as hidden field in
         the form to prevent CSRF attacks.
-
+        :eval_url: External URL for rule evaluation. If defined this URL is
+        called to evaluate client side rules with a AJAX request. The rule
+        to evaluate is provided in a GET request in the "rule" paramenter.
+        The return Value is a JSON response with success attribute set
+        depending on the result of the evaluation and the error message in
+        the data attribute in case the evaluation fails.
         """
         self._config = config
         self._item = item
         self._dbsession = dbsession
         self._request = request
         self._csrf_token = csrf_token
+        self._eval_url = eval_url
         if translate:
             self._translate = translate
         else:
@@ -274,7 +280,8 @@ class Form(object):
     def add_validator(self, validator):
         return self.external_validators.append(validator)
 
-    def render(self, values={}, page=0, buttons=True, previous_values=None):
+    def render(self, values={}, page=0, buttons=True,
+               previous_values=None, outline=True):
         """Returns the rendererd form as an HTML string.
 
         :values: Dictionary with values to be prefilled/overwritten in
@@ -282,6 +289,8 @@ class Form(object):
         :previous_values: Dictionary of values of the last saved state
         of the item. If provided a diff between the current and previous
         values will be renderered in readonly mode.
+        :outline: Boolean flag to indicate that the outline for pages
+        should be rendered. Defaults to true.
         :returns: Rendered form.
 
         """
@@ -300,10 +309,11 @@ class Form(object):
 
         renderer = FormRenderer(self, self._translate)
         form = renderer.render(values=values, buttons=buttons,
-                               previous_values=previous_values)
+                               previous_values=previous_values,
+                               outline=outline)
         # TODO: Can happen: Error while parsing form in htmlfill: %s. Hint See
         # 'https://github.com/formencode/formencode/issues/57desc (ti)
-        # <2014-03-21 10:29> 
+        # <2014-03-21 10:29>
         return htmlfill.render(form, values)
 
     def _add_error(self, fieldname, error):
@@ -760,7 +770,16 @@ class Field(object):
         options = []
         if self.get_type() == 'manytoone':
             options.append(("None", "", True))
-        clazz = self._get_sa_mapped_class()
+        try:
+            clazz = self._get_sa_mapped_class()
+        except:
+            # Catch exception here. This exception can happen when
+            # rendering the form in the preview of the formeditor. In
+            # this case the item is None and will fail to get the mapped
+            # class.
+            log.error("Can not get a mappend class for '%s' "
+                      "to load the option from db" % self.name)
+            return options
         items = self._form._dbsession.query(clazz)
         for item in items:
             if self._config.renderer and self._config.renderer.filter:
