@@ -42,6 +42,8 @@ def get_renderer(field, translate):
             return HiddenFieldRenderer(field, translate)
         elif renderer.render_type == "html":
             return HTMLRenderer(field, translate)
+        elif renderer.render_type == "formbareditor":
+            return FormbarEditorRenderer(field, translate)
     else:
         # Try to determine the datatype of the field and set approriate
         # renderer.
@@ -89,7 +91,8 @@ class FormRenderer(Renderer):
         self.translate = translate
         self.template = template_lookup.get_template("form.mako")
 
-    def render(self, buttons=True, values=None, previous_values=None):
+    def render(self, buttons=True, values=None,
+               previous_values=None, outline=True):
         """Returns the rendered form as string.
 
         :buttons: Boolean flag to indicate if the form buttons should be
@@ -97,6 +100,8 @@ class FormRenderer(Renderer):
         :previous_values: Dictionary of values of the last saved state
         of the item. If provided a diff between the current and previous
         values will be renderered in readonly mode.
+        :outline: Boolean flag to indicate that the outline for pages
+        should be rendered. Defaults to true.
         :returns: rendered form.
 
         """
@@ -106,7 +111,7 @@ class FormRenderer(Renderer):
             previous_values = {}
         html = []
         html.append(self._render_form_start())
-        html.append(self._render_form_body(values, previous_values))
+        html.append(self._render_form_body(values, previous_values, outline))
         if not self._form._config.readonly and buttons:
             html.append(self._render_form_buttons())
         html.append(self._render_form_end())
@@ -121,19 +126,22 @@ class FormRenderer(Renderer):
                 'method': self._form._config.method,
                 'autocomplete': self._form._config.autocomplete,
                 'enctype': self._form._config.enctype,
+                'evalurl': self._form._eval_url or "",
                 '_': self.translate}
         html.append('<form id="%(id)s" class="%(css)s" role="form" '
                     'method="%(method)s" action="%(action)s" '
-                    'autocomplete="%(autocomplete)s" enctype="%(enctype)s">' % attr)
+                    'autocomplete="%(autocomplete)s" enctype="%(enctype)s" '
+                    'evalurl="%(evalurl)s">' % attr)
         # Add hidden field with csrf_token if this is not None.
         if self._form._csrf_token:
             html.append('<input type="hidden" name="csrf_token" value="%s"/>'
                         % self._form._csrf_token)
         return "".join(html)
 
-    def _render_form_body(self, values, previous_values):
+    def _render_form_body(self, values, previous_values, render_outline):
         values = {'form': self._form,
                   '_': self.translate,
+                  'render_outline': render_outline,
                   'previous_values': previous_values,
                   'values': values}
         return self.template.render(**values)
@@ -375,6 +383,14 @@ class SelectionFieldRenderer(FieldRenderer):
         FieldRenderer.__init__(self, field, translate)
         self.template = template_lookup.get_template("selection.mako")
 
+class FormbarEditorRenderer(FieldRenderer):
+    """A Renderer to render the formbar editor widget used to edit
+    formbar form definitons."""
+
+    def __init__(self, field, translate):
+        FieldRenderer.__init__(self, field, translate)
+        self.template = template_lookup.get_template("formbareditor.mako")
+
 # TODO: Check which of the following Renderers are needed (ti). It looks
 # like they are outdated as they are using old FormAlchemy fa_*.mako
 # templates <2013-10-11 22:31>
